import vl from 'vega-lite-api';
import { range, hcl } from 'd3';

// Use a different hue for each zip code class
// defined by the first two digits.
const numHues = 99;
const colorScale = {
  range: range(numHues).map(i => hcl(i / numHues * 360, 80, 90).hex())
};

export const viz = () => vl
  .markCircle({size: 2, opacity: 0.4})
  .data('https://raw.githubusercontent.com/vega/vega-datasets/master/data/zipcodes.csv')
  .transform(vl.calculate('substring(datum.zip_code, 0, 2)').as('digit'))
  .project(vl.projection('albersUsa'))
  .encode(
    vl.longitude().fieldQ('longitude'),
    vl.latitude().fieldQ('latitude'),
    vl.color().fieldN('digit').legend(null).scale(colorScale)
  )
  .width(960)
  .height(500)
  .autosize({type: 'fit-x', contains: 'padding'})
  .config({view: {stroke: null}});